# Encoding


This subsystem synchronizes the client and the server's encodings so that each end can use the most appropriate
codecs for exchanging data.


## Implementations

| Component         | Link                                                                                                             |
|-------------------|------------------------------------------------------------------------------------------------------------------|
| client            | [xpra.client.subsystem.encodings](https://github.com/Xpra-org/xpra/blob/master/xpra/client/subsystem/encodings.py) |
| client connection | [xpra.server.source.encodings](https://github.com/Xpra-org/xpra/blob/master/xpra/server/source/encodings.py)     |
| server            | [xpra.server.subsystem.encoding](https://github.com/Xpra-org/xpra/blob/master/xpra/server/subsystem/encoding.py) |



## Capabilities

TBD

## Network Packets

TBD
